@@ -18,6 +18,9 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+#include "attachwarner.h"
+#include "pluginconfig.h"
+
 #include <gtk/gtk.h>
 
 #include "gettext.h"
@@ -62,8 +65,7 @@ static void attwarner_prefs_create_widget_func(PrefsPage * _page,
 	GtkTextBuffer *buffer;
 	GtkWidget *skip_quotes_checkbox;
 	GtkWidget *skip_fwd_redir_checkbox;
-	GtkTooltips *skip_quotes_tooltip;
-	GtkTooltips *skip_fwd_redir_tooltip;
+	CLAWS_TIP_DECL();
 
 	vbox = gtk_vbox_new(FALSE, 6);
 	hbox = gtk_hbox_new(FALSE, 6);
@@ -92,9 +94,9 @@ static void attwarner_prefs_create_widget_func(PrefsPage * _page,
 	    	 attwarnerprefs.skip_quotes);
 	gtk_box_pack_start(GTK_BOX(vbox), skip_quotes_checkbox, FALSE, FALSE, 0);
 	gtk_widget_show(skip_quotes_checkbox);
-	skip_quotes_tooltip = gtk_tooltips_new();
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(skip_quotes_tooltip), skip_quotes_checkbox,
-			_("Exclude quoted lines from checking for the regular expressions above"), NULL);
+
+	CLAWS_SET_TIP(skip_quotes_checkbox,
+			_("Exclude quoted lines from checking for the regular expressions above"));
 	page->skip_quotes_checkbox = skip_quotes_checkbox;
 	
 	skip_fwd_redir_checkbox = gtk_check_button_new_with_label(_("Skip forwards and redirections"));
@@ -102,9 +104,9 @@ static void attwarner_prefs_create_widget_func(PrefsPage * _page,
 	    	 attwarnerprefs.skip_forwards_and_redirections);
 	gtk_box_pack_start(GTK_BOX(vbox), skip_fwd_redir_checkbox, FALSE, FALSE, 0);
 	gtk_widget_show(skip_fwd_redir_checkbox);
-	skip_fwd_redir_tooltip = gtk_tooltips_new();
-	gtk_tooltips_set_tip(GTK_TOOLTIPS(skip_fwd_redir_tooltip), skip_fwd_redir_checkbox,
-			_("Don't check for missing attachments when forwarding or redirecting messages"), NULL);
+
+	CLAWS_SET_TIP(skip_fwd_redir_checkbox,
+			_("Don't check for missing attachments when forwarding or redirecting messages"));
 	page->skip_forwards_and_redirections = skip_fwd_redir_checkbox;
 
 	gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 6);
