@@ -19,8 +19,8 @@
 
 #include <math.h>
 
-#include "prefs.h"
 #include "prefs_gtk.h"
+#include "common/prefs.h"
 #include "common/utils.h"
 #include "common/defs.h"
 #include "gtk/gtkutils.h"
@@ -36,9 +36,22 @@
 #include "notification_command.h"
 #include "notification_lcdproc.h"
 #include "notification_trayicon.h"
+#include "notification_indicator.h"
+#include "notification_hotkeys.h"
 
 #include "notification_foldercheck.h"
 
+#ifdef HAVE_LIBNOTIFY
+/* allow infinite timeout with libnotify */
+# define TIMEOUT_SPINNER_MIN     0.0
+#else
+/* don't allow infinite timeout with self-handled popups */
+# define TIMEOUT_SPINNER_MIN     0.2
+#endif
+
+#define TIMEOUT_SPINNER_MAX  3600.0
+#define TIMEOUT_SPINNER_STEP    0.5
+
 typedef struct
 {
 	PrefsPage page;
@@ -141,6 +154,28 @@ typedef struct {
 NotifyTrayiconPage trayicon_page;
 #endif
 
+#ifdef NOTIFICATION_INDICATOR
+typedef struct {
+	PrefsPage page;
+	GtkWidget *indicator_enabled;
+	GtkWidget *indicator_cont_enable;
+	GtkWidget *indicator_register;
+	GtkWidget *indicator_hide_minimized;
+}NotifyIndicatorPage;
+NotifyIndicatorPage indicator_page;
+#endif
+
+#ifdef NOTIFICATION_HOTKEYS
+typedef struct {
+    PrefsPage page;
+    GtkWidget *hotkeys_enabled;
+    GtkWidget *hotkeys_cont_enable;
+    GtkWidget *hotkeys_toggle_mainwindow;
+}NotifyHotkeysPage;
+NotifyHotkeysPage hotkeys_page;
+#endif
+
+
 PrefParam
 		notify_param[] =
 		{
@@ -262,6 +297,18 @@ PrefParam
 #endif /* HAVE_LIBNOTIFY */
 #endif
 
+#ifdef NOTIFICATION_INDICATOR
+				{	"indicator_enabled", "FALSE", &notify_config.indicator_enabled, P_BOOL,
+					NULL, NULL, NULL},
+                {   "indicator_hide_minimized", "FALSE", &notify_config.indicator_hide_minimized, P_BOOL,
+                    NULL, NULL, NULL},
+#endif /* NOTIFICATION_INDICATOR */
+#ifdef NOTIFICATION_HOTKEYS
+                {   "hotkeys_enabled", "FALSE", &notify_config.hotkeys_enabled, P_BOOL,
+                    NULL, NULL, NULL},
+                {   "hotkeys_toggle_mainwindow", "", &notify_config.hotkeys_toggle_mainwindow,
+                    P_STRING, NULL, NULL, NULL},
+#endif /* NOTIFICATION_HOTKEYS */
 				{ NULL, NULL, NULL, P_OTHER, NULL, NULL, NULL } };
 
 static void notify_create_prefs_page(PrefsPage*, GtkWindow*, gpointer);
@@ -321,6 +368,21 @@ static void notify_trayicon_popup_enable_set_sensitivity(GtkToggleButton*,
 #endif
 #endif
 
+#ifdef NOTIFICATION_INDICATOR
+static void notify_create_indicator_page(PrefsPage*, GtkWindow*, gpointer);
+static void notify_destroy_indicator_page(PrefsPage*);
+static void notify_save_indicator(PrefsPage*);
+static void notify_indicator_enable_set_sensitivity(GtkToggleButton*, gpointer);
+#endif /* NOTIFICATION_INDICATOR */
+
+#ifdef NOTIFICATION_HOTKEYS
+static void notify_create_hotkeys_page(PrefsPage*, GtkWindow*, gpointer);
+static void notify_destroy_hotkeys_page(PrefsPage*);
+static void notify_save_hotkeys(PrefsPage*);
+static void notify_hotkeys_enable_set_sensitivity(GtkToggleButton*, gpointer);
+#endif /* NOTIFICATION_HOTKEYS */
+
+
 static gint conv_color_to_int(GdkColor*);
 
 void notify_gtk_init(void)
@@ -337,6 +399,24 @@ void notify_gtk_init(void)
 	notify_page.page.save_page = notify_save_prefs;
 	prefs_gtk_register_page((PrefsPage*) &notify_page);
 
+#ifdef NOTIFICATION_HOTKEYS
+    {
+        static gchar *hotkeys_path[4];
+
+        hotkeys_path[0] = _("Plugins");
+        hotkeys_path[1] = _("Notification");
+        hotkeys_path[2] = _("Hotkeys");
+        hotkeys_path[3] = NULL;
+
+        hotkeys_page.page.path = hotkeys_path;
+        hotkeys_page.page.create_widget = notify_create_hotkeys_page;
+        hotkeys_page.page.destroy_widget = notify_destroy_hotkeys_page;
+        hotkeys_page.page.save_page = notify_save_hotkeys;
+        prefs_gtk_register_page((PrefsPage*) &hotkeys_page);
+    }
+#endif /* NOTIFICATION_HOTKEYS */
+
+
 #ifdef NOTIFICATION_BANNER
 	{
 		static gchar *banner_path[4];
@@ -421,6 +501,23 @@ void notify_gtk_init(void)
 		prefs_gtk_register_page((PrefsPage*) &trayicon_page);
 	}
 #endif /* NOTIFICATION_TRAYICON */
+
+#ifdef NOTIFICATION_INDICATOR
+	{
+		static gchar *indicator_path[4];
+
+		indicator_path[0] = _("Plugins");
+		indicator_path[1] = _("Notification");
+		indicator_path[2] = _("Indicator");
+		indicator_path[3] = NULL;
+
+		indicator_page.page.path = indicator_path;
+		indicator_page.page.create_widget = notify_create_indicator_page;
+		indicator_page.page.destroy_widget = notify_destroy_indicator_page;
+		indicator_page.page.save_page = notify_save_indicator;
+		prefs_gtk_register_page((PrefsPage*) &indicator_page);
+	}
+#endif /* NOTIFICATION_INDICATOR */
 }
 
 void notify_gtk_done(void)
@@ -443,6 +540,9 @@ void notify_gtk_done(void)
 #ifdef NOTIFICATION_TRAYICON
 	prefs_gtk_unregister_page((PrefsPage*) &trayicon_page);
 #endif
+#ifdef NOTIFICATION_INDICATOR
+	prefs_gtk_unregister_page((PrefsPage*) &indicator_page);
+#endif
 }
 
 void notify_save_config(void)
@@ -911,7 +1011,7 @@ static void notify_create_popup_page(PrefsPage *page, GtkWindow *window,
 	label = gtk_label_new(_("Popup timeout:"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
-	spinner = gtk_spin_button_new_with_range(0.2, 60., 0.5);
+	spinner = gtk_spin_button_new_with_range(TIMEOUT_SPINNER_MIN, TIMEOUT_SPINNER_MAX, TIMEOUT_SPINNER_STEP);
 	gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spinner), 1);
 	timeout = notify_config.popup_timeout/1000.;
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinner), timeout);
@@ -1247,7 +1347,7 @@ static void notify_save_command(PrefsPage *page)
 
 	tmp_str = gtk_entry_get_text(GTK_ENTRY(command_page.command_line));
 	if(notify_config.command_line)
-	g_free(notify_config.command_line);
+      g_free(notify_config.command_line);
 	notify_config.command_line = g_strdup(tmp_str);
 }
 
@@ -1375,11 +1475,14 @@ static void notify_create_trayicon_page(PrefsPage *page, GtkWindow *window,
 	GtkWidget *hbox;
 	GtkWidget *button;
 
-#ifdef HAVE_LIBNOTIFY
-	GtkWidget *svbox;
-	GtkWidget *ssvbox;
+#if defined(HAVE_LIBNOTIFY)
 	GtkWidget *frame;
+	GtkWidget *svbox;
 	GtkWidget *label;
+#endif
+
+#ifdef HAVE_LIBNOTIFY
+	GtkWidget *ssvbox;
 	GtkWidget *spinner;
 	gdouble timeout;
 #endif
@@ -1489,7 +1592,7 @@ static void notify_create_trayicon_page(PrefsPage *page, GtkWindow *window,
 	label = gtk_label_new(_("Popup timeout:"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
-	spinner = gtk_spin_button_new_with_range(0.2, 60., 0.5);
+	spinner = gtk_spin_button_new_with_range(TIMEOUT_SPINNER_MIN, TIMEOUT_SPINNER_MAX, TIMEOUT_SPINNER_STEP);
 	gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spinner), 1);
 	timeout = notify_config.trayicon_popup_timeout/1000.;
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinner), timeout);
@@ -1609,6 +1712,229 @@ static void notify_trayicon_popup_enable_set_sensitivity(GtkToggleButton *bu,
 
 #endif /* NOTIFICATION_TRAYICON */
 
+#ifdef NOTIFICATION_INDICATOR
+
+#define NOTIFICATION_INDICATOR_REGISTER_PATH ".config/indicators/messages/applications"
+
+static gboolean indicator_register_file_exists(void)
+{
+  gboolean retval;
+  gchar *filepath;
+  filepath = g_strconcat(get_home_dir(), "/" NOTIFICATION_INDICATOR_REGISTER_PATH "/claws-mail", NULL);
+  retval = is_file_exist(filepath);
+  g_free(filepath);
+  return retval;
+}
+
+static gboolean indicator_register_file_create(void)
+{
+  FILE *fp;
+  gchar *path, *filepath;
+  gboolean success;
+
+  /* make sure directory path exists */
+  path = g_strconcat(get_home_dir(), "/" NOTIFICATION_INDICATOR_REGISTER_PATH, NULL);
+  if(!is_dir_exist(path)) {
+    if(make_dir_hier(path) != -1)
+      debug_print("Notification plugin: Created directory '%s'\n", path);
+     else {
+       debug_print("Notification plugin: Error creating directory '%s'\n", path);
+       g_free(path);
+       return FALSE;
+     }
+  }
+
+  /* create register file */
+  filepath = g_strconcat(path, "/claws-mail", NULL);
+  g_free(path);
+  fp = fopen(filepath, "w");
+  success = (fp != NULL);
+  if(fp) {
+    fprintf(fp, "%s\n", get_desktop_file());
+    fclose(fp);
+    debug_print("Notification plugin: Created desktop indicator file '%s'\n", filepath);
+  }
+  else
+    debug_print("Notification plugin: Could not create desktop indicator file '%s'\n", filepath);
+  g_free(filepath);
+
+  return success;
+}
+
+static gboolean indicator_register_file_remove(void)
+{
+  gchar *filepath;
+  int retval;
+
+  filepath = g_strconcat(get_home_dir(), "/" NOTIFICATION_INDICATOR_REGISTER_PATH "/claws-mail", NULL);
+  retval = claws_unlink(filepath);
+  if(retval != -1)
+    debug_print("Notification plugin: Deleted file '%s'\n", filepath);
+  else
+    debug_print("Notification plugin: Error deleting file '%s'\n", filepath);
+  g_free(filepath);
+
+  return (retval != -1);
+}
+
+static void notify_create_indicator_page(PrefsPage *page, GtkWindow *window,
+		gpointer data)
+{
+	GtkWidget *pvbox;
+	GtkWidget *vbox;
+	GtkWidget *checkbox;
+	GtkWidget *ind_reg;
+
+	pvbox = gtk_vbox_new(FALSE, 20);
+	gtk_container_set_border_width(GTK_CONTAINER(pvbox), 10);
+
+	/* Enable indicator */
+	checkbox = gtk_check_button_new_with_label(_("Add to Indicator Applet"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbox),
+			notify_config.indicator_enabled);
+	gtk_box_pack_start(GTK_BOX(pvbox), checkbox, FALSE, FALSE, 0);
+	g_signal_connect(G_OBJECT(checkbox), "toggled",
+			G_CALLBACK(notify_indicator_enable_set_sensitivity), NULL);
+	indicator_page.indicator_enabled = checkbox;
+
+	/* Container vbox for greying out everything */
+	vbox = gtk_vbox_new(FALSE, 10);
+	gtk_box_pack_start(GTK_BOX(pvbox), vbox, FALSE, FALSE, 0);
+	indicator_page.indicator_cont_enable = vbox;
+
+	/* hide when minimized */
+	checkbox = gtk_check_button_new_with_label(_("Hide mainwindow when minimized"));
+	gtk_box_pack_start(GTK_BOX(indicator_page.indicator_cont_enable), checkbox, FALSE, FALSE, 0);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbox), notify_config.indicator_hide_minimized);
+	indicator_page.indicator_hide_minimized = checkbox;
+
+	/* register */
+	ind_reg = gtk_check_button_new_with_label(_("Register Claws Mail"));
+	gtk_box_pack_start(GTK_BOX(indicator_page.indicator_cont_enable), ind_reg, FALSE, FALSE, 0);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ind_reg), indicator_register_file_exists());
+	indicator_page.indicator_register = ind_reg;
+
+	notify_indicator_enable_set_sensitivity(GTK_TOGGLE_BUTTON(indicator_page.indicator_enabled), NULL);
+	gtk_widget_show_all(pvbox);
+	indicator_page.page.widget = pvbox;
+}
+
+static void notify_destroy_indicator_page(PrefsPage *page)
+{
+}
+
+static void notify_save_indicator(PrefsPage *page)
+{
+    gboolean ind_reg;
+
+	notify_config.indicator_enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(indicator_page.indicator_enabled));
+
+	notify_config.indicator_hide_minimized = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(indicator_page.indicator_hide_minimized));
+
+	ind_reg = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(indicator_page.indicator_register));
+	if(ind_reg) {
+	  if(!indicator_register_file_exists())
+	    indicator_register_file_create();
+	}
+	else {
+	  if(indicator_register_file_exists())
+	    indicator_register_file_remove();
+	}
+
+	notification_indicator_destroy();
+	notification_update_indicator();
+}
+
+static void notify_indicator_enable_set_sensitivity(GtkToggleButton *button,
+		gpointer data)
+{
+	gboolean active;
+	active = gtk_toggle_button_get_active
+	(GTK_TOGGLE_BUTTON(indicator_page.indicator_enabled));
+	gtk_widget_set_sensitive(indicator_page.indicator_cont_enable, active);
+}
+#endif /* NOTIFICATION_INDICATOR */
+
+#ifdef NOTIFICATION_HOTKEYS
+static void notify_create_hotkeys_page(PrefsPage *page, GtkWindow *window, gpointer data)
+{
+    GtkWidget *pvbox;
+    GtkWidget *vbox;
+    GtkWidget *checkbox;
+    GtkWidget *label;
+    gchar *markup;
+    GtkWidget *table;
+    GtkWidget *entry;
+
+    pvbox = gtk_vbox_new(FALSE, 20);
+    gtk_container_set_border_width(GTK_CONTAINER(pvbox), 10);
+
+    /* Enable hotkeys */
+    checkbox = gtk_check_button_new_with_label(_("Enable global hotkeys"));
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbox),  notify_config.hotkeys_enabled);
+    gtk_box_pack_start(GTK_BOX(pvbox), checkbox, FALSE, FALSE, 0);
+    g_signal_connect(G_OBJECT(checkbox), "toggled",
+        G_CALLBACK(notify_hotkeys_enable_set_sensitivity), NULL);
+    hotkeys_page.hotkeys_enabled = checkbox;
+
+    /* Container vbox for greying out everything */
+    vbox = gtk_vbox_new(FALSE, 10);
+    gtk_box_pack_start(GTK_BOX(pvbox), vbox, FALSE, FALSE, 0);
+    hotkeys_page.hotkeys_cont_enable = vbox;
+
+    /* description */
+    label = gtk_label_new("");
+    markup = g_markup_printf_escaped("Examples for hotkeys include <b>%s</b> and <b>%s</b>", "<control><shift>F11", "<alt>N");
+    gtk_label_set_markup(GTK_LABEL(label), markup);
+    gtk_misc_set_alignment(GTK_MISC(label), 0., 0.);
+    g_free(markup);
+    gtk_box_pack_start(GTK_BOX(hotkeys_page.hotkeys_cont_enable), label, FALSE, FALSE, 0);
+
+    /* table for entry fields */
+    table = gtk_table_new(1, 2, FALSE);
+    gtk_box_pack_start(GTK_BOX(hotkeys_page.hotkeys_cont_enable), table, FALSE, FALSE, 0);
+
+    /* toggle mainwindow */
+    label = gtk_label_new(_("Toggle minimize:"));
+    gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 0, 1);
+    entry = gtk_entry_new();
+    gtk_table_attach_defaults(GTK_TABLE(table), entry, 1, 2, 0, 1);
+    if(notify_config.hotkeys_toggle_mainwindow)
+      gtk_entry_set_text(GTK_ENTRY(entry), notify_config.hotkeys_toggle_mainwindow);
+    hotkeys_page.hotkeys_toggle_mainwindow = entry;
+
+    notify_hotkeys_enable_set_sensitivity(GTK_TOGGLE_BUTTON(hotkeys_page.hotkeys_enabled), NULL);
+    gtk_widget_show_all(pvbox);
+    hotkeys_page.page.widget = pvbox;
+}
+
+static void notify_destroy_hotkeys_page(PrefsPage *page)
+{
+}
+
+static void notify_save_hotkeys(PrefsPage *page)
+{
+    const gchar *tmp_str;
+    notify_config.hotkeys_enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(hotkeys_page.hotkeys_enabled));
+
+    tmp_str = gtk_entry_get_text(GTK_ENTRY(hotkeys_page.hotkeys_toggle_mainwindow));
+    if(notify_config.hotkeys_toggle_mainwindow)
+      g_free(notify_config.hotkeys_toggle_mainwindow);
+    notify_config.hotkeys_toggle_mainwindow = g_strdup(tmp_str);
+
+    notification_hotkeys_update_bindings();
+}
+
+static void notify_hotkeys_enable_set_sensitivity(GtkToggleButton *button,
+        gpointer data)
+{
+    gboolean active;
+    active = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(hotkeys_page.hotkeys_enabled));
+    gtk_widget_set_sensitive(hotkeys_page.hotkeys_cont_enable, active);
+}
+#endif /* hotkeys */
+
+
 /* This feels so wrong... */
 static gint conv_color_to_int(GdkColor *color)
 {
