@@ -526,6 +526,7 @@ xmlDocPtr rssyl_fetch_feed(const gchar *url, time_t last_update, gchar **title,
 	tmptitle = rssyl_strreplace(*title, "/", "\\");
 	dir = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, RSSYL_DIR,
 			G_DIR_SEPARATOR_S, tmptitle, NULL);
+	g_free(tmptitle);
 
 	if( !is_dir_exist(dir) ) {
 		if( make_dir(dir) < 0 ) {
@@ -536,8 +537,6 @@ xmlDocPtr rssyl_fetch_feed(const gchar *url, time_t last_update, gchar **title,
 		}
 	}
 
-	g_free(tmptitle);
-
 	g_free(rootnode);
 	g_free(dir);
 
@@ -971,7 +970,9 @@ void rssyl_read_existing(RSSylFolderItem *ritem)
 static gint rssyl_cb_feed_compare(const RSSylFeedItem *a,
 		const RSSylFeedItem *b)
 {
-	gboolean date_publ_eq = FALSE, link_eq = FALSE;
+	gboolean date_publ_eq = FALSE, link_eq = FALSE, title_eq = FALSE;
+	gboolean no_link = FALSE, no_title = FALSE;
+	gchar *atit = NULL, *btit = NULL;
 
 	if( a == NULL || b == NULL )
 		return 1;
@@ -986,19 +987,29 @@ static gint rssyl_cb_feed_compare(const RSSylFeedItem *a,
 		return 1;
 	}
 
-	/* Ok, we have no ID to aid us. Let's have a look at item timestamps
-	 * and item link. */
+	/* Ok, we have no ID to aid us. Let's have a look at item timestamps,
+	 * item link and title. */
+	if( (a->link != NULL) && (b->link != NULL) ) {
+		if( strcmp(a->link, b->link) == 0 )
+			link_eq = TRUE;
+	} else
+		no_link = TRUE;
 
-	if( ((a->link != NULL) && (b->link != NULL) &&
-				(strcmp(a->link, b->link) == 0)) ) {
-		link_eq = TRUE;
-	}
+	if( (a->title != NULL) && (b->title != NULL) ) {
+		atit = conv_unmime_header(a->title, CS_UTF_8);
+		btit = conv_unmime_header(b->title, CS_UTF_8);
+		if( strcmp(atit, btit) == 0 )
+			title_eq = TRUE;
+		g_free(atit);
+		g_free(btit);
+	} else
+		no_title = TRUE;
 
 	/* If there's no 'published' timestamp for the item, we can only judge
-	 * by item link - 'modified' timestamp can have changed if the item was
-	 * updated recently. */
+	 * by item link and title - 'modified' timestamp can have changed if the
+	 * item was updated recently. */
 	if( a->date_published <= 0 ) {
-		if( link_eq == TRUE )
+		if( link_eq && (title_eq || no_title) )
 			return 0;
 	}
 
@@ -1009,29 +1020,26 @@ static gint rssyl_cb_feed_compare(const RSSylFeedItem *a,
 
 	/* If 'published' time and item link match, it is reasonable to assume
 	 * it's this item. */
-	if( link_eq && date_publ_eq )
+	if( (link_eq || no_link) && date_publ_eq )
+		return 0;
+
+	/* Last ditch effort - if everything else is missing, at least titles
+	 * should match. */
+	if( no_link && title_eq )
 		return 0;
 
 	/* We don't know this item. */
 	return 1;
 }
 
-static gboolean rssyl_feed_item_changed(RSSylFeedItem *old_item, RSSylFeedItem *new_item)
-{
-	/* if both have text ... */
-	if( old_item->text && new_item->text ) {
-		if( strcmp(old_item->text, new_item->text) ) {	/* ... compare texts */
-			debug_print("item texts differ\n");
-			return TRUE;
-		}
-	} else {
-		/* if atleast one has some text, they differ */
-		if( old_item->text || new_item->text ) {
-			debug_print("+/- text\n");
-			return TRUE;
-		}
-	}
+enum {
+	ITEM_UNCHANGED,
+	ITEM_CHANGED_TEXTONLY,
+	ITEM_CHANGED
+};
 
+static gint rssyl_feed_item_changed(RSSylFeedItem *old_item, RSSylFeedItem *new_item)
+{
 	/* if both have title ... */
 	if( old_item->title && new_item->title ) {
 		gchar *old = conv_unmime_header(old_item->title, CS_UTF_8);
@@ -1039,16 +1047,16 @@ static gboolean rssyl_feed_item_changed(RSSylFeedItem *old_item, RSSylFeedItem *
 		if( strcmp(old, new) ) {	/* ... compare "unmimed" titles */
 			g_free(old);
 			g_free(new);
-			debug_print("item titles differ\n");
-			return TRUE;
+			debug_print("RSSyl: item titles differ\n");
+			return ITEM_CHANGED;
 		}
 		g_free(old);
 		g_free(new);
 	} else {
 		/* if atleast one has a title, they differ */
 		if( old_item->title || new_item->title ) {
-			debug_print("+/- title\n");
-			return TRUE;
+			debug_print("RSSyl: +/- title\n");
+			return ITEM_CHANGED;
 		}
 	}
 
@@ -1059,31 +1067,54 @@ static gboolean rssyl_feed_item_changed(RSSylFeedItem *old_item, RSSylFeedItem *
 		if( strcmp(old, new) ) {	/* ... compare "unmimed" authors */
 			g_free(old);
 			g_free(new);
-			debug_print("item authors differ\n");
-			return TRUE;
+			debug_print("RSSyl: item authors differ\n");
+			return ITEM_CHANGED;
 		}
 		g_free(old);
 		g_free(new);
 	} else {
 		/* if atleast one has author, they differ */
 		if( old_item->author || new_item->author ) {
-			debug_print("+/- author\n");
-			return TRUE;
+			debug_print("RSSyl: +/- author\n");
+			return ITEM_CHANGED;
+		}
+	}
+
+	/* if both have text ... */
+	if( old_item->text && new_item->text ) {
+		if( strcmp(old_item->text, new_item->text) ) {	/* ... compare texts */
+			debug_print("RSSyl: item texts differ\n");
+			return ITEM_CHANGED_TEXTONLY;
+		}
+	} else {
+		/* if atleast one has some text, they differ */
+		if( old_item->text || new_item->text ) {
+			debug_print("RSSyl: +/- text\n");
+			return ITEM_CHANGED_TEXTONLY;
 		}
 	}
 
 	/* they don't seem to differ */
-	return FALSE;
+	return ITEM_UNCHANGED;
 }
 
 /* rssyl_feed_item_exists()
  *
  * Returns 1 if a feed item already exists locally, 2 if there's a changed
- * item with link that already belongs to existing item, 0 if item is new.
+ * item with link that already belongs to existing item, 3 if only item's
+ * text has changed, 0 if item is new.
  */
+enum {
+	EXISTS_NEW,
+	EXISTS_UNCHANGED,
+	EXISTS_CHANGED,
+	EXISTS_CHANGED_TEXTONLY
+};
+
 static guint rssyl_feed_item_exists(RSSylFolderItem *ritem,
 		RSSylFeedItem *fitem, RSSylFeedItem **oldfitem)
 {
+	gint changed;
 	GSList *item = NULL;
 	RSSylFeedItem *efitem = NULL;
 	g_return_val_if_fail(ritem != NULL, FALSE);
@@ -1095,9 +1126,12 @@ static guint rssyl_feed_item_exists(RSSylFolderItem *ritem,
 	if( (item = g_slist_find_custom(ritem->contents,
 					(gconstpointer)fitem, (GCompareFunc)rssyl_cb_feed_compare)) ) {
 		efitem = (RSSylFeedItem *)item->data;
-		if(  rssyl_feed_item_changed(efitem, fitem) ) {
+		if( (changed = rssyl_feed_item_changed(efitem, fitem)) > EXISTS_NEW ) {
 			*oldfitem = efitem;
-			return 2;
+			if (changed == ITEM_CHANGED_TEXTONLY)
+				return EXISTS_CHANGED_TEXTONLY;
+			else
+				return EXISTS_CHANGED;
 		}
 		return 1;
 	}
@@ -1191,7 +1225,7 @@ gboolean rssyl_add_feed_item(RSSylFolderItem *ritem, RSSylFeedItem *fitem)
 		debug_print("RSSyl: This item already exists, skipping...\n");
 		return FALSE;
 	}
-	if( dif == 2 && oldfitem != NULL ) {
+	if( dif >= 2 && oldfitem != NULL ) {
 		debug_print("RSSyl: Item changed, removing old one and adding new...\n");
 		ritem->contents = g_slist_remove(ritem->contents, oldfitem);
 		g_remove(oldfitem->realpath);
@@ -1241,7 +1275,7 @@ gboolean rssyl_add_feed_item(RSSylFolderItem *ritem, RSSylFeedItem *fitem)
 				strlen("Subject: "), FALSE, CS_UTF_8);
 			err |= (fprintf(f, "Subject: %s\n", tmp) < 0);
 		} else
-			err |= (fprintf(f, "Subject: %s\n", tmp) < 0);
+			err |= (fprintf(f, "Subject: %s\n", fitem->title) < 0);
 	}
 
 	if( (tmpurl = fitem->link) == NULL ) {
@@ -1324,14 +1358,17 @@ gboolean rssyl_add_feed_item(RSSylFolderItem *ritem, RSSylFeedItem *fitem)
 
 	err |= (fclose(f) == EOF);
 
-	flags->perm_flags = MSG_NEW | MSG_UNREAD;
-	flags->tmp_flags = 0;
-
 	if (!err) {
 		g_return_val_if_fail(template != NULL, FALSE);
 		d = folder_item_add_msg(&ritem->item, template, flags, TRUE);
 	}
 	g_free(template);
+
+	if (ritem->silent_update == 2
+			|| (ritem->silent_update == 1 && dif == EXISTS_CHANGED_TEXTONLY))
+		procmsg_msginfo_unset_flags(
+				folder_item_get_msginfo((FolderItem *)ritem, d), MSG_NEW | MSG_UNREAD, 0);
+	else
 	
 	debug_print("RSSyl: folder_item_add_msg(): %d, err %d\n", d, err);
 
