@@ -35,10 +35,14 @@
 
 gint plugin_init(gchar **error)
 {
+#ifdef G_OS_UNIX
 	bindtextdomain(TEXTDOMAIN, LOCALEDIR);
+#else
+	bindtextdomain(TEXTDOMAIN, get_locale_dir());
+#endif
 	bind_textdomain_codeset(TEXTDOMAIN, "UTF-8");
 
-	if( !check_plugin_version(MAKE_NUMERIC_VERSION(2,10,0,177),
+	if( !check_plugin_version(MAKE_NUMERIC_VERSION(3,5,0,47),
 				VERSION_NUMERIC, PLUGIN_NAME, error) )
 		return -1;
 
