@@ -3,7 +3,7 @@
   FILE: icalvalue.c
   CREATOR: eric 02 May 1999
   
-  $Id: icalderivedvalue.c.in,v 1.1.2.2 2005/07/15 09:21:03 twb Exp $
+  $Id: icalderivedvalue.c.in,v 1.1.2.3 2009-10-30 09:27:25 colin Exp $
 
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -113,7 +113,7 @@ void icalvalue_set_x(icalvalue* value, const char* v) {
  }
 const char* icalvalue_get_x(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
+    icalerror_check_arg_rz( (value!=0),"value");
     icalerror_check_value_type(value, ICAL_X_VALUE);
     return ((struct icalvalue_impl*)value)->x_value;
 }
@@ -202,7 +202,6 @@ icalvalue_get_trigger(icalvalue* value)
     struct icalvalue_impl *impl = (struct icalvalue_impl*)value;
     struct icaltriggertype tr;
 
-    icalerror_check_arg( (value!=0),"value");
     icalerror_check_arg( (value!=0),"value");
 
     if(impl->kind == ICAL_DATETIME_VALUE){
@@ -354,9 +353,9 @@ void icalvalue_set_query(icalvalue* value, const char* v) {
  }
 const char* icalvalue_get_query(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_QUERY_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_string;
+	icalerror_check_arg_rz( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_QUERY_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_string;
 }
 
 
@@ -378,9 +377,9 @@ void icalvalue_set_date(icalvalue* value, struct icaltimetype v) {
  }
 struct icaltimetype icalvalue_get_date(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_DATE_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_time;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_DATE_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_time;
 }
 
 
@@ -402,9 +401,9 @@ void icalvalue_set_attach(icalvalue* value, struct icalattachtype v) {
  }
 struct icalattachtype icalvalue_get_attach(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_ATTACH_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_attach;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_ATTACH_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_attach;
 }
 
 
@@ -426,9 +425,9 @@ void icalvalue_set_geo(icalvalue* value, struct icalgeotype v) {
  }
 struct icalgeotype icalvalue_get_geo(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_GEO_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_geo;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_GEO_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_geo;
 }
 
 
@@ -450,9 +449,9 @@ void icalvalue_set_datetimedate(icalvalue* value, struct icaltimetype v) {
  }
 struct icaltimetype icalvalue_get_datetimedate(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_DATETIMEDATE_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_time;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_DATETIMEDATE_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_time;
 }
 
 
@@ -474,9 +473,9 @@ void icalvalue_set_status(icalvalue* value, enum icalproperty_status v) {
  }
 enum icalproperty_status icalvalue_get_status(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_STATUS_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_enum;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_STATUS_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_enum;
 }
 
 
@@ -498,9 +497,9 @@ void icalvalue_set_transp(icalvalue* value, enum icalproperty_transp v) {
  }
 enum icalproperty_transp icalvalue_get_transp(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_TRANSP_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_enum;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_TRANSP_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_enum;
 }
 
 
@@ -530,9 +529,9 @@ void icalvalue_set_string(icalvalue* value, const char* v) {
  }
 const char* icalvalue_get_string(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_STRING_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_string;
+	icalerror_check_arg_rz( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_STRING_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_string;
 }
 
 
@@ -562,9 +561,9 @@ void icalvalue_set_text(icalvalue* value, const char* v) {
  }
 const char* icalvalue_get_text(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_TEXT_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_string;
+	icalerror_check_arg_rz( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_TEXT_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_string;
 }
 
 
@@ -594,9 +593,9 @@ void icalvalue_set_binary(icalvalue* value, const char* v) {
  }
 const char* icalvalue_get_binary(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_BINARY_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_string;
+	icalerror_check_arg_rz( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_BINARY_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_string;
 }
 
 
@@ -618,9 +617,9 @@ void icalvalue_set_period(icalvalue* value, struct icalperiodtype v) {
  }
 struct icalperiodtype icalvalue_get_period(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_PERIOD_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_period;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_PERIOD_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_period;
 }
 
 
@@ -642,9 +641,9 @@ void icalvalue_set_float(icalvalue* value, float v) {
  }
 float icalvalue_get_float(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_FLOAT_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_float;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_FLOAT_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_float;
 }
 
 
@@ -666,9 +665,9 @@ void icalvalue_set_integer(icalvalue* value, int v) {
  }
 int icalvalue_get_integer(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_INTEGER_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_int;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_INTEGER_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_int;
 }
 
 
@@ -690,9 +689,9 @@ void icalvalue_set_class(icalvalue* value, enum icalproperty_class v) {
  }
 enum icalproperty_class icalvalue_get_class(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_CLASS_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_enum;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_CLASS_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_enum;
 }
 
 
@@ -722,9 +721,9 @@ void icalvalue_set_uri(icalvalue* value, const char* v) {
  }
 const char* icalvalue_get_uri(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_URI_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_string;
+	icalerror_check_arg_rz( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_URI_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_string;
 }
 
 
@@ -746,9 +745,9 @@ void icalvalue_set_time(icalvalue* value, struct icaltimetype v) {
  }
 struct icaltimetype icalvalue_get_time(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_TIME_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_time;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_TIME_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_time;
 }
 
 
@@ -770,9 +769,9 @@ void icalvalue_set_duration(icalvalue* value, struct icaldurationtype v) {
  }
 struct icaldurationtype icalvalue_get_duration(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_DURATION_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_duration;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_DURATION_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_duration;
 }
 
 
@@ -794,9 +793,9 @@ void icalvalue_set_boolean(icalvalue* value, int v) {
  }
 int icalvalue_get_boolean(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_BOOLEAN_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_int;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_BOOLEAN_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_int;
 }
 
 
@@ -826,9 +825,9 @@ void icalvalue_set_caladdress(icalvalue* value, const char* v) {
  }
 const char* icalvalue_get_caladdress(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_CALADDRESS_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_string;
+	icalerror_check_arg_rz( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_CALADDRESS_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_string;
 }
 
 
@@ -850,9 +849,9 @@ void icalvalue_set_action(icalvalue* value, enum icalproperty_action v) {
  }
 enum icalproperty_action icalvalue_get_action(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_ACTION_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_enum;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_ACTION_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_enum;
 }
 
 
@@ -874,9 +873,9 @@ void icalvalue_set_datetime(icalvalue* value, struct icaltimetype v) {
  }
 struct icaltimetype icalvalue_get_datetime(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_DATETIME_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_time;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_DATETIME_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_time;
 }
 
 
@@ -898,9 +897,9 @@ void icalvalue_set_utcoffset(icalvalue* value, int v) {
  }
 int icalvalue_get_utcoffset(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_UTCOFFSET_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_int;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_UTCOFFSET_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_int;
 }
 
 
@@ -922,7 +921,7 @@ void icalvalue_set_method(icalvalue* value, enum icalproperty_method v) {
  }
 enum icalproperty_method icalvalue_get_method(icalvalue* value) {
 
-    icalerror_check_arg( (value!=0),"value");
-    icalerror_check_value_type(value, ICAL_METHOD_VALUE);
-    return ((struct icalvalue_impl*)value)->data.v_enum;
+	icalerror_check_arg( (value!=0),"value");
+	icalerror_check_value_type(value, ICAL_METHOD_VALUE);
+	return ((struct icalvalue_impl*)value)->data.v_enum;
 }
