@@ -34,10 +34,14 @@
 
 gint plugin_init(gchar **error)
 {
+#ifdef G_OS_UNIX
 	bindtextdomain(TEXTDOMAIN, LOCALEDIR);
+#else
+	bindtextdomain(TEXTDOMAIN, get_locale_dir());
+#endif
 	bind_textdomain_codeset (TEXTDOMAIN, "UTF-8");
 
-	if (!check_plugin_version(MAKE_NUMERIC_VERSION(3,3,1,16),
+	if (!check_plugin_version(MAKE_NUMERIC_VERSION(3,6,1,27),
 				VERSION_NUMERIC, _("vCalendar"), error))
 		return -1;
 
